<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\Middleware;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Services\RoleAndPermissionsService;
use App\Services\ZhenKhService;
use Carbon\Exceptions\UnitNotConfiguredException;
use Closure;
use Illuminate\Auth\Access\AuthorizationException;
use Illuminate\Contracts\Auth\Factory as Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Symfony\Component\HttpKernel\Exception\UnauthorizedHttpException;
use App\Support\Traits\Helpers;


class Authenticate
{
    use Helpers;
    /**
     * The authentication guard factory instance.
     *
     * @var Auth
     */
    protected $auth;

    /**
     * Create a new middleware instance.
     *
     * @param  Auth  $auth
     */
    public function __construct(Auth $auth)
    {
        $this->auth = $auth;
    }

    /**
     * Handle an incoming request.
     *
     * @param  Request  $request
     * @param  Closure  $next
     * @param  string|null  $guard
     * @return mixed
     *
     * @throws AuthorizationException
     */
    public function handle($request, Closure $next, $guard = null)
    {
        $token = trim(str_ireplace('bearer', '', $request->header('authorization')));
        $decodeToken = $this->decodeToken($token);

        $params = $request->all();
        if(!isset($params['platform']) || empty($params['platform'])){
            throw new UnauthorizedHttpException('JWTAuth','平台参数错误');
        }
        switch($params['platform']){
            case 'zkh' : $platformToken = app(ZhenKhService::class)->apiService->getPlatformInfo('platform_token');break;
        }
        if(empty($platformToken) || $decodeToken['hash'] !== $platformToken){
            throw new UnauthorizedHttpException('JWTAuth','无效的平台token');
        }

        if(empty($decodeToken) || (!is_array($decodeToken) && !$decodeToken['hash'])){
            throw new UnauthorizedHttpException('JWTAuth', 'Unable to authenticate with invalid token.');
        }

        return $next($request);
    }
}
