<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\V1;

use App\Services\ZhenKhService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Http\Controllers\V1\Controller;
use App\Support\Traits\Helpers;

class ZhenkhController extends Controller
{
    use Helpers;


    public function __construct(ZhenKhService $zhenKhService)
    {
       $this->zhenKhService= $zhenKhService;
    }

    /**
     * 震坤行订单发货
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function orderDelivery(Request $request)
    {
        $message = [
            'delivery_code.required' => "发货单号必传",
        ];
        $this->validateRequest($request, $message);

        try{
            $params = $request->all();
            $this->zhenKhService->sendDeliveryOrder($params['delivery_code']);
            return Response::success(null, '操作成功');
        }catch(\Exception $exception){
            return Response::fail($exception->getMessage(),500);
        }
    }

    public function getOrderDeliveryPdf(Request $request)
    {
        $message = [
            'delivery_code.required' => "发货单号必传",
        ];
        $this->validateRequest($request, $message);

        try{
            $params = $request->all();
            $result = $this->zhenKhService->getDeliveryOrderPdf($params['delivery_code']);
            if($result){
                return Response::success($result, '操作成功');
            }else{
                return Response::success([],'获取pdf失败，无法找到相应的pdf文件' );
            }
        }catch(\Exception $exception){
            return Response::fail($exception->getMessage(),500);
        }
    }

    public function orderConfirm(Request $request)
    {
        $message = [
            'order_no.required' => "发货单号必传",
        ];
        $this->validateRequest($request, $message);

        try{
            $params = $request->all();
            $result = $this->zhenKhService->orderConfirm($params['order_no']);
            if($result){
                return Response::success(null, '操作成功');
            }
        }catch(\Exception $exception){
            return Response::fail($exception->getMessage(),500);
        }
    }
}
