<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Providers;

use App\Repositories\Contracts\SysLogRepository;
use App\Services\Kafka\KafkaService;
use App\Services\SysLogService;
use GuzzleHttp\Client;
use Illuminate\Support\ServiceProvider;
use Illuminate\Support\Facades\Schema;
use Laravel\Lumen\Application as LumenApplication;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register()
    {
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
	    Schema::defaultStringLength(191);

        if( $this->app instanceof LumenApplication ){
            $this->app->configure('kafka');
            $this->setupConfig();
        }

        //单例绑定，初始化kafka
        $this->app->singleton(KafkaService::class,function($app){
            return new KafkaService(config('kafka.kafka'));
        });

        $this->app->singleton(SysLogService::class,function($app){
            return new SysLogService(app(SysLogRepository::class));
        });

        $this->app->singleton(\GuzzleHttp\Client::class,function($app){
            return new Client();
        });


        $this->commands([
            \App\Console\Commands\IntegleJobCommand::class,
            \App\Console\Commands\WuxiLabJobCommand::class,
            \App\Console\Commands\BideJobCommand::class,
            \App\Console\Commands\BjsJobCommand::class,
            \App\Console\Commands\ZhenkhJobCommand::class,
            \App\Console\Commands\KafkaConsumerCommand::class
        ]);

    }

    protected function setupConfig()
    {
        $path = dirname(__DIR__, 2).'/config/kafka.php';
        $this->mergeConfigFrom($path, 'kafka');
    }
}
