<?php

namespace App\Repositories\Eloquent;

use App\Repositories\Contracts\RhawnRawRepository;
use App\Repositories\Criteria\RequestCriteria;
use App\Repositories\Eloquent\BaseRepository;

use App\Repositories\Models\RhawnProducts;
use App\Repositories\Models\RhawnRaw;
use Illuminate\Support\Facades\DB;
use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class RhawnRawRepositoryEloquent extends BaseRepository implements RhawnRawRepository
{
    protected $fieldSearchable = [
    ];

    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return RhawnRaw::class;
    }

    /**
     * Boot up the repository, pushing criteria.
     *
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function boot()
    {
        $this->pushCriteria(app(RequestCriteria::class));
    }

    public function total(){
       return $this->count();
    }

    public function getRawProductList($pageSize = 1000, $offset = 0)
    {
        $rawList = RhawnRaw::query()
            ->join('chemicals', 'chemicals.c_id','raw.c_id')
            ->offset($offset)
            ->limit($pageSize)
            ->get();

        return $rawList->toArray();
    }

    public function getRawProductsThroughtCode($rawCode)
    {
        $raw = RhawnRaw::query()
            ->join('chemicals', 'chemicals.c_id','raw.c_id');
        if(!is_array($rawCode)){
            $raw->where('r_code',$rawCode);
        }else{
            $raw->whereIn('r_code',!is_array($rawCode));
        }
        $rawList = $raw->get();
        return $rawList->toArray();
    }

    public function getProductPackage($rawProductIds)
    {
        $packagesList = RhawnProducts::query()
            ->join('raw','raw.r_id','products.r_id')
            ->join('chemicals', 'chemicals.c_id','raw.c_id');

        if(is_array($rawProductIds)){
            $packagesList = $packagesList->whereIn('raw.r_id',$rawProductIds);
        }else{
            $packagesList = $packagesList->where('raw.r_id',$rawProductIds);
        }
        $packagesList = $packagesList->get();

        return $packagesList->toArray();
    }

    public function getProductPackagesThroughGroupByPackUnit()
    {
        $packages = RhawnProducts::query()
            ->select('p_pack','p_pack_unit')
            ->groupBy('p_pack','p_pack_unit')
            ->get();

        return $packages->toArray();
    }
}
