<?php

namespace App\Repositories\Eloquent;

use App\Repositories\Contracts\RhawnSoitemsRepository;
use App\Repositories\Contracts\RhawnSordersRepository;
use App\Repositories\Criteria\RequestCriteria;
use App\Repositories\Eloquent\BaseRepository;

use App\Repositories\Models\RhawnSoitems;
use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class RhawnSoitemsRepositoryEloquent extends BaseRepository implements RhawnSoitemsRepository
{
    protected $fieldSearchable = [
    ];

    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return RhawnSoitems::class;
    }

    /**
     * Boot up the repository, pushing criteria.
     *
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function boot()
    {
        $this->pushCriteria(app(RequestCriteria::class));
    }

    /**
     * 获取订单详情
     * @param $orderId
     * @return \Illuminate\Database\Eloquent\Builder[]|\Illuminate\Database\Eloquent\Collection
     */
    public function getSorderItemsDetailFromOrderId($orderId)
    {
        $order = app(RhawnSordersRepository::class)->find($orderId);
        if(!$order){
            throw new \LogicException('该订单不存在!',500);
        }

        //查询订单的详情
        $soItems = RhawnSoitems::query()
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
            ->where('soitems.so_id',$order->so_id)->get();

        return $soItems;
    }

    public function getSorderItemsDetailFromItemId($itemId,$pid=null)
    {
        //查询订单的详情
        $soItems = RhawnSoitems::query()
            ->join('sorders','sorders.so_id','soitems.so_id')
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
            ->where('soitems.si_id',$itemId);
        if(!is_null($pid)){
            $soItems = $soItems->where('soitems.p_id',$pid);
        }
        $soItems = $soItems->get();

        return $soItems;
    }

    /**
     * 根据si_id获取订单明细项
     * @param $si_id
     * @return \Illuminate\Database\Eloquent\Builder[]|\Illuminate\Database\Eloquent\Collection
     */
    public function getSorderItemFromItemId($si_id)
    {
        $item = $this->find($si_id);
        if(!$item){
            throw new \LogicException('该订单项不存在!',500);
        }

        //查询订单的详情
        $soItems = RhawnSoitems::query()
            ->join('products','soitems.p_id','products.p_id')
            ->where('soitems.si_id',$si_id)->get();

        return $soItems;
    }

    public function getOrderItemsStockFromItemIds($id)
    {
        if(!is_array($id)){
            $item = $this->find($id);
            $id = (array)$id;
        }else{
            $item = RhawnSoitems::query()->whereIn('si_id',$id)->get();
        }
        if(!$item){
            throw new \LogicException('该订单项不存在!',500);
        }

        //查询订单的详情
        $soItemStock = RhawnSoitems::query()
            ->join('dpdetail','dpdetail.si_id','soitems.si_id')
            ->join('pstock','pstock.pstk_id','dpdetail.pstk_id')
            ->join('products','soitems.p_id','products.p_id')
            ->whereIn('soitems.si_id',$id)
            ->where('si_if_cancel',0)
            //->where('dpdetail.dpd_invoiced','=',0)
            ->get();

        return $soItemStock;
    }
}
