<?php

namespace App\Repositories\Eloquent;

use App\Repositories\Contracts\RhawnSordersRepository;
use App\Repositories\Criteria\RequestCriteria;
use App\Repositories\Models\RhawnSorders;
use App\Repositories\Eloquent\BaseRepository;

use Illuminate\Support\Facades\DB;
use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class RhawnSordersRepositoryEloquent extends BaseRepository implements RhawnSordersRepository
{
    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return RhawnSorders::class;
    }

    /**
     * 返回指定订单编号的订单信息
     * @param $order_no
     * @return mixed
     */
    public function getSorderFromOrderNo($orderNo)
    {
        $where = [
            'so_no' => $orderNo
        ];
        return $this->findWhere($where)->first();
    }

    public function getSorderFromOrderCusPo($orderNo)
    {
        $where = [
            'so_cus_po' => $orderNo
        ];
        return $this->findWhere($where)->first();
    }

    /**
     * 获取订单详情
     * @param $orderNo
     * @return mixed
     */
    public function getSorderItemsFromOrderNo($orderNo){
        $soItems = $this
            ->join('soitems','soitems.so_id','sorders.so_id')
            ->where('sorders.so_no',$orderNo)->get();

        return $soItems;
    }

    /**
     * 获取订单相关信息（包括，产品，客户，品牌等）
     * @param $so_id
     * @return mixed
     */
    public function getSorderDetailFromOrderId($so_id)
    {
        $sOrderInfo = $this
            ->join('customers','sorders.cus_id','customers.cus_id')
            ->where('sorders.so_id',$so_id)
            ->get();
        if(!$sOrderInfo){
            return ;
        }
        $sOrderInfo = current($sOrderInfo->toArray());

        $items = DB::connection('bh_mysql')->table('soitems')
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
        ->where('soitems.so_id',$so_id)
        ->get();

        if(!$items){
            $sOrderInfo['items'] = [];
        }
        $sOrderInfo['items'] = $items->toArray();

       return $sOrderInfo;
    }
}
