<?php

namespace App\Services;

use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;


class BhProductsService
{
    /**
     * 保存bide平台的产品数据
     */
    public function storeBideProducts($bideProducts)
    {
       if (!is_array($bideProducts) || empty($bideProducts)) {
            return false;
        }

        try {

            $id = 0;

            $dbConnect = DB::connection('bh_mysql');
            $dbConnect->beginTransaction();

            $chemicalsRow = $dbConnect->table('chemicals')
                ->where('c_cas', $bideProducts[0]['CASNumber'])
                ->get()->toArray();
            if (empty($chemicalsRow)) {
                return false;
            }
            $chemicalsRow = current($chemicalsRow);

            $dbConnect->table('products')
                ->where('c_id', $chemicalsRow->c_id)
                ->where('b_id', 10)
                ->update(['p_status' => 0, 'p_show' => 0, 'modifytime' => time()]);


            foreach ($bideProducts as $product) {
                if ($product['Weight'] > 0) {
                    $p_tod = '现货';
                } else {
                    $p_tod = '无货，请咨询';
                }
                $p_code = $product['ProductNum'] . '-' . $product['PackSize'];

                $productRow = $dbConnect->table('products')
                    ->where('b_id', 10)
                    ->where('c_id', $chemicalsRow->c_id)
                    ->where('p_code', 'like', $p_code)
                    ->get()->toArray();

                $pro_data = [];
                if (empty($productRow)) {

                    $pro_data['b_id'] = 10;
                    $pro_data['c_id'] = $chemicalsRow->c_id;
                    $pro_data['p_code'] = $p_code;
                    if (!$product['ProductCName']) {
                        $pro_data['p_cn_name'] = '';
                    } else {
                        $pro_data['p_cn_name'] = $product['ProductCName'];
                    }
                    if (!$product['ProductEName']) {
                        $pro_data['p_en_name'] = '';
                    } else {
                        $pro_data['p_en_name'] = $product['ProductEName'];
                    }
                    $pro_data['p_level'] = $product['Purity'];
                    $pro_data['p_pack'] = $product['PackSize'];
                    $pro_data['p_price'] = $product['PriceB'];
                    $pro_data['p_tod'] = $p_tod;
                    $pro_data['p_weight'] = '0.01';
                    $pro_data['p_status'] = 1;
                    $pro_data['p_show'] = 1;
                    $pro_data['prom_from'] = 0;
                    $pro_data['prom_to'] = 0;

                    $id = $dbConnect->table('products')->insertGetId($pro_data);

                } else {

                    $productRow = current($productRow);

                    $pro_data['p_status'] = 1;
                    $pro_data['p_show'] = 1;
                    $pro_data['p_price'] = $product['PriceB'];
                    $pro_data['p_tod'] = $p_tod;
                    $pro_data['modifytime'] = time();
                    $dbConnect->table('products')
                        ->where('p_id', $productRow->p_id)
                        ->update($pro_data);

                    $id = $productRow->p_id;
                }
            }

            $dbConnect->commit();

            SimpleLogs::writeLog('Bide p_id : '.$id.' cas : '.$chemicalsRow->c_cas. ' 更新成功，更新时间:'.date('Y-m-d H:i:s',time()),__CLASS__.':storeBjsProducts');

            return true;

        }catch(\Exception $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':storeBjsProducts', 'error');
            $dbConnect->rollback();
            throw $exception;
        }
    }

    /**
     * 保存bjs平台的产品数据
     */
    public function storeBjsProducts($bideProducts)
    {
        if (!is_array($bideProducts) || empty($bideProducts)) {
            return false;
        }

        try {

            $id = 0;

            $dbConnect = DB::connection('bh_mysql');
            $dbConnect->beginTransaction();

            $chemicalsRow = $dbConnect->table('chemicals')
                ->where('c_cas', $bideProducts[0]['CASNumber'])
                ->get()->toArray();
            if (empty($chemicalsRow)) {
                return false;
            }
            $chemicalsRow = current($chemicalsRow);

            $dbConnect->table('products')
                ->where('c_id', $chemicalsRow->c_id)
                ->where('b_id', 175)
                ->update(['p_status' => 0, 'p_show' => 0, 'modifytime' => time()]);


            foreach ($bideProducts as $product) {
                if ($product['Weight'] > 0) {
                    $p_tod = '现货';
                } else {
                    $p_tod = '无货，请咨询';
                }
                $p_code = $product['ProductNum'] . '-' . $product['PackSize'];

                $productRow = $dbConnect->table('products')
                    ->where('b_id', 175)
                    ->where('c_id', $chemicalsRow->c_id)
                    ->where('p_code', 'like', $p_code)
                    ->get()->toArray();

                $pro_data = [];
                if (empty($productRow)) {

                    $pro_data['b_id'] = 175;
                    $pro_data['c_id'] = $chemicalsRow->c_id;
                    $pro_data['p_code'] = $p_code;
                    if (!$product['ProductCName']) {
                        $pro_data['p_cn_name'] = '';
                    } else {
                        $pro_data['p_cn_name'] = $product['ProductCName'];
                    }
                    if (!$product['ProductEName']) {
                        $pro_data['p_en_name'] = '';
                    } else {
                        $pro_data['p_en_name'] = $product['ProductEName'];
                    }
                    $pro_data['p_level'] = $product['Purity'];
                    $pro_data['p_pack'] = $product['PackSize'];
                    $pro_data['p_price'] = $product['Price'];
                    $pro_data['p_tod'] = $p_tod;
                    $pro_data['p_weight'] = '0.01';
                    $pro_data['p_status'] = 1;
                    $pro_data['p_show'] = 0;
                    $pro_data['prom_from'] = 0;
                    $pro_data['prom_to'] = 0;

                    $id = $dbConnect->table('products')->insertGetId($pro_data);

                } else {

                    $productRow = current($productRow);

                    $pro_data['p_status'] = 1;
                    $pro_data['p_show'] = 0;
                    $pro_data['p_price'] = $product['Price'];
                    $pro_data['p_tod'] = $p_tod;
                    $pro_data['modifytime'] = time();
                    $dbConnect->table('products')
                        ->where('p_id', $productRow->p_id)
                        ->update($pro_data);

                    $id = $productRow->p_id;
                }
            }

            $dbConnect->commit();

            SimpleLogs::writeLog('Bjs p_id : '.$id.' cas : '.$chemicalsRow->c_cas. ' 更新成功，更新时间:'.date('Y-m-d H:i:s',time()),__CLASS__.':storeBjsProducts');

            return true;

        }catch(\Exception $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':storeBjsProducts', 'error');
            $dbConnect->rollback();
            throw $exception;
        }
    }
}
