<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\Kafka\KafkaService;
use App\Services\ThirdPlatform\Api\BjsApiService;
use App\Services\ThirdPlatform\PlatformAbstractService;
use App\Support\Facades\SimpleLogs;
use App\Support\Traits\Helpers;

class BjsService
{
    public function __construct()
    {
        $this->apiService = (new BjsApiService(app(ThirdApiPlatformRepository::class)));
    }

    public function batchUpdateProducts($params = null)
    {
        $path = config('filesystems.disks.local.root').'/upload/'.$params;
        $generator = Helpers::yieldLoadCsv($path);

        // yield 循环逐行读取csv内容
        while ($generator->valid()) {
            $content = $generator->current();
            app(KafkaService::class)->produerSend(
                [
                    'params' => ['cas' => current($content)],
                    'consumer' => __CLASS__,
                    'method' => 'batchUpdateApi'

                ]
            );
            $generator->next();
        }
        //$generator->rewind();

    }

    public function batchUpdateApi($params)
    {
        $result = $this->apiService->pushBatchUpdateProduct($params['cas']);
        if(!$result){
            return ;
        }
        try{
            $result = app(BhProductsService::class)->storeBjsProducts($result);
        }catch(\Exception $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':batchUpdateApi', 'error');
        }
    }
}
