<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services;

use App\Repositories\Contracts\RhawnRawRepository;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class RhawnChemicalsService
{
    public $rhawnRawRepository = null;

    public function __construct(RhawnRawRepository $rhawnRawRepository)
    {
        $this->rhawnRawRepository = $rhawnRawRepository;
    }

    /**
     * @param int $offse
     * @param int $limit
     */
    public function getChemicalRawList($offset = 0, $limit = 100)
    {
        $rawList = $this->rhawnRawRepository->getRawProductList($limit, $offset);
        return $rawList;
    }

    public function getChemicalPackage($rawIds)
    {
        $packageList = $this->rhawnRawRepository->getProductPackage($rawIds);
        return $packageList;
    }

    public function getProductPackagesThroughGroupByPackUnit()
    {
        return $this->rhawnRawRepository->getProductPackagesThroughGroupByPackUnit();
    }

    public function getChemicalRawThroughtCode($rawCode)
    {
        return $this->rhawnRawRepository->getRawProductsThroughtCode($rawCode);
    }


    /**
     * 保存震坤行同步商品数据
     * @param $goods
     */
    public function updateZhenkhGoods($goods)
    {
        try{
            $dbConnect = DB::connection('rhawn_mysql');

            $zkhGoods = [];
            $zkhGoods['zg_sku'] = $goods['zkhSku'];
            $zkhGoods['zg_r_sku'] = $goods['supplierSkuNo'];
            if(isset($goods['addressList']['0'])){
                $zkhGoods['zg_addr'] = implode(',',$goods['addressList']);
            }
            $zkhGoods['zg_unit'] = $goods['priceUnit'];

            if($zkhGoods['zg_r_sku'] != ''){
                $zkhGoodsResult = $dbConnect->table('products')
                    ->where('p_code',$zkhGoods['zg_r_sku'])
                    ->get()->toArray();
                if($zkhGoodsResult){
                    $zkhGoodsResult = current($zkhGoodsResult);
                    $zkhGoods['zg_r_pid'] = $zkhGoodsResult->p_id;


                    $row = $dbConnect->table('zkh_goods')
                        ->where('zg_r_sku',$zkhGoods['zg_r_sku'])
                        ->where('zg_r_pid',$zkhGoods['zg_r_pid'])
                        ->get()->toArray();

                    if(count($row) == 0){
                        $id = $dbConnect->table('zkh_goods')->insertGetId($zkhGoods);
                        SimpleLogs::writeLog('zkh_goods 新增 id : '.$id.' 成功.', 'sql insert');
                        $row = $dbConnect->table('zkh_goods')->where('zg_id',$id)->get()->toArray();
                    }
                    if($row){
                        return current($row);
                    }
                }
            }
            return null;

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),'updateZhenkhGoods ','error');
            throw $exception;
        }
    }

    public function updateSyncRunTime($goods)
    {
        $dbConnect = DB::connection('rhawn_mysql');
        return $dbConnect->table('zkh_goods')->where('zg_id',$goods['zg_id'])->update(['zg_sync_time' => time()]);
    }

    public function getRawProductsThroughPid($pId)
    {
        try{
            $dbConnect = DB::connection('rhawn_mysql');

            $product = $dbConnect->table('products')
                ->where('p_id',$pId)
                ->get()->toArray();
            if(count($product) > 0){
                return current($product);
            }

            return null;

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),'getRawProductsThroughPid ','error');
            throw $exception;
        }
    }

    /**
     * @获取震坤行对应的商品sku
     * @param $pCode
     * @return array
     */
    public function getZkhGoodsSku($pCode)
    {
        $dbConnect = DB::connection('rhawn_mysql');
        $model = $dbConnect->table('zkh_goods');
        if(is_array($pCode)){
            $model->whereIn('zg_r_pid',$pCode);
        }else{
            $model->where('zg_r_pid',$pCode);
        }
        return $model->get()->toArray();
    }
}
