<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\ThirdPlatform\Api;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\ThirdPlatform\PlatformAbstractService;
use App\Support\Traits\HttpClientHelpers;


class BjsApiService extends PlatformAbstractService
{
    use HttpClientHelpers;

    public function __construct(ThirdApiPlatformRepository $thirdApiPlatformRepository)
    {
        parent::__construct($thirdApiPlatformRepository);
        $this->setPlatformName('bjs');
        $this->getPlatformInfo();
    }

    /**
     * 批量更新商品信息
     * @param $product
     * @return bool
     */
    public function pushBatchUpdateProduct($product)
    {
        try{
            if($this->checkPlatformStatus()){
                $params = [];
                $params['CASNumber'] = $this->mergeApiMetaData($product);

                $uri = $this->platformInfo['platform_url'].'/api/BJS/GetStockPriceDataThree';
                $response = $this->getPostClient($uri,$params,null,[
                    'Client_id' => $this->platformInfo['platform_params']['Client_id'],
                    'Client_secret' => $this->platformInfo['platform_params']['Client_secret']
                ],false);

                return $this->apiResponse($response);
            }
        }catch(\Exception $e){
            return $this->requestError($e);
        }
    }

    /**
     * 整理组装 api 数据
     * @param $metaData
     * @return array
     */
    public function mergeApiMetaData($metaData)
    {
        return $metaData;
    }

    protected function apiResponse($response)
    {
        $decodeResponse = json_decode($response,true);
        if($decodeResponse['status'] == '1' && $decodeResponse['code'] == '0'){
            if(!empty($decodeResponse['data'])){
                return $decodeResponse['data'];
            }
        }elseif($decodeResponse['status'] == '0'){
            if(!is_array($decodeResponse['data'])){
                return false;
            }
        }
        return false;
    }

    protected function requestError($err)
    {
       return false;
    }
}
