<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services;

use App\ImportExport\BaseExport;
use App\ImportExport\WuxiLab\WuxiLabExport;
use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Repositories\Models\RhawnProducts;
use App\Services\Kafka\KafkaService;
use App\Services\ThirdPlatform\Api\WuxiApiService;
use App\Services\ThirdPlatform\PlatformAbstractService;
use App\Support\Facades\SimpleKafka;
use App\Support\Facades\SimpleLogs;
use App\Support\Traits\Helpers;
use Illuminate\Filesystem\Filesystem;
use longlang\phpkafka\Protocol\ApiVersions\ApiVersionsResponse;

class WuxiLabService
{

    public function __construct()
    {
        $this->apiService = (new WuxiApiService(app(ThirdApiPlatformRepository::class)));
        $this->rhawnChemicalsService = app(RhawnChemicalsService::class);
    }

    /**
     * 批量更新商品
     */
    public function batchUpdateProducts($params = null)
    {
        $status = $this->apiService->checkPlatformStatus();
        if($status){
            $limit = $this->apiService->getPlatformInfo('platform_params')['batchNums'];
            $page = 0;

            while(true) {
                $rawList = $this->rhawnChemicalsService->getChemicalRawList($page * $limit, $limit);
                if (!$rawList) {
                    break;
                }
                $rawIdList = [];
                foreach ($rawList as $raw) {
                    $rawIdList[] = $raw['r_id'];
                }
                $packages = $this->rhawnChemicalsService->getChemicalPackage($rawIdList);
                $newPackages = [];
                if($packages){
                    foreach($packages as $pack){
                        $newPackages[$pack['r_code']] = $pack;
                    }
                }
                if(!empty($rawList)){
                    SimpleKafka::produerSend(
                        [
                            'params' => ['rawList' => $rawList,'packageList' => $newPackages],
                            'consumer' => __CLASS__,
                            'method' => 'batchUpdateToWuxiLab'

                        ],
                        'wuxilab'
                    );
                }
                break;
            }
        }
    }

    public function test($rawCode)
    {
        try{
            $rawsList = $this->rhawnChemicalsService->getChemicalRawThroughtCode($rawCode);
            if($rawsList){
                foreach ($rawsList as $raw) {
                    $rawIdList[] = $raw['r_id'];
                }
                $packages = $this->rhawnChemicalsService->getChemicalPackage($rawIdList);
                $newPackages = [];
                if($packages){
                    foreach($packages as $pack){
                        $newPackages[$pack['r_code']] = $pack;
                    }
                }
                /*$path = app(WuxiLabExport::class)->saveExcel(
                    ['rawList' => $rawsList,'packageList' => $newPackages],
                    'package'
                );
                if($path){
                    list($file,$expend) = explode('.',$path);
                    $newPath = $file.'.'.strtolower($expend);
                    $cmd = 'mv '.storage_path('app/'.$path).' '.storage_path('app/'.$newPath);
                    trim(shell_exec("$cmd 2>&1"));
                    $filePathList = explode('/',$file);
                    $fileName = $filePathList[count($filePathList) - 1];
                    $result = $this->apiService->pushBatchUploadFile('package',$fileName, $this->apiService->backgroundLogin());
                    if($result){
                        $cmd = 'rm -rf '.storage_path('app/'.$newPath);
                        trim(shell_exec("$cmd 2>&1"));
                        SimpleLogs::writeLog('文件名为:'.$fileName.'路径:'.$newPath.'药明康德后台上传完成', __CLASS__.':processNotExistProductsUpdate');
                    }
                }*/


                $result = $this->apiService->pushBatchUpdateProduct(['rawList' => $rawsList,'packageList' => $newPackages]);
                var_dump($result);
            }
        }catch(\Throwable $exception){
            var_dump($exception->getMessage());
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':processNotExistProductsUpdate', 'error');
        }
    }

    /**
     * @批量后台请求更新规格
     * @param null $params
     */
    public function batchUpdatePackagesInfo($params = null)
    {
        $token = $this->getToken();

        $wuxiLabPackage = ['bottle','box','bp','case','ea','g','gal','hole','kg','kit','l','m','m2','mg','ml','mm','mmol','mu',
            'ng','nmole','od','package','pair','piece','pmole','RL','sets','test', 'unit','vial','xa','µci','µg','µl','µmol'];

        //$path = config('filesystems.disks.local.root').'/upload/'.$params;
        //$generator = Helpers::yieldLoadCsv($path);

        // yield 循环逐行读取csv内容
        /*while ($generator->valid()) {
            $content = $generator->current();
            if(in_array($content[1],$wuxiLabPackage)){
                $this->apiService->pushBatchUpdatePackages([
                    'unit_quantity' => $content[0], 'unit_type' => $content[1], 'unit_description' => $content[0].$content[1]
                ],$token);
            }
            usleep(30000);
            $generator->next();
        }*/
        $packageList = $this->apiService->getPackageList($token);

        $rhawnChemicalsService = app(RhawnChemicalsService::class);
        $packagesUnit = $rhawnChemicalsService->getProductPackagesThroughGroupByPackUnit();

        foreach($packagesUnit as $package){
            if(!empty($packageList)){
                $exist = 0;
                foreach($packageList as $p){
                    $name = $package['p_pack'].$package['p_pack_unit'];
                    if($name == $p['unitDescription']){
                        $exist = 1;
                    }
                }
                if(!$exist){
                    if(!in_array($package['p_pack_unit'],$wuxiLabPackage)){
                        continue;
                    }
                    $this->apiService->pushBatchUpdatePackages([
                        'unit_quantity' => $package['p_pack'], 'unit_type' => $package['p_pack_unit'], 'unit_description' => $package['p_pack'].$package['p_pack_unit']
                    ],$token);
                }
            }
        }
    }

    /**
     * @处理不存在商品的更新
     * @param $params
     * @return false|void
     */
    public function processProductsUpdateThroughtExcel($params)
    {
        if(!isset($params['products']) || empty($params['products'])){
            return false;
        }

        try{
            $rawsList = $this->rhawnChemicalsService->getChemicalRawThroughtCode($params['products']);
            if($rawsList){
                foreach ($rawsList as $raw) {
                    $rawIdList[] = $raw['r_id'];
                }
                $packages = $this->rhawnChemicalsService->getChemicalPackage($rawIdList);
                $newPackages = [];
                if($packages){
                    foreach($packages as $pack){
                        $newPackages[$pack['r_code']] = $pack;
                    }
                }
                $path = app(WuxiLabExport::class)->saveExcel(
                    ['rawList' => $rawsList,'packageList' => $newPackages]
                );
                if($path){
                    list($file,$expend) = explode('.',$path);
                    $newPath = $file.'.'.strtolower($expend);
                    $cmd = 'mv '.storage_path('app/'.$path).' '.storage_path('app/'.$newPath);
                    trim(shell_exec("$cmd 2>&1"));
                    $filePathList = explode('/',$file);
                    $fileName = $filePathList[count($filePathList) - 1];
                    $result = $this->apiService->pushBatchUploadFile($params['type'],$fileName, $this->getToken());
                    if($result){
                        SimpleLogs::writeLog('文件名为:'.$fileName.'路径:'.$newPath.'药明康德后台上传完成', __CLASS__.':processNotExistProductsUpdate');
                    }
                }
            }
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':processNotExistProductsUpdate', 'error');
        }
    }

    /**
     * @批量更新商品
     * @param $updateData
     */
    public function batchUpdateToWuxiLab($updateData)
    {
        if(!isset($updateData['rawList']) || empty($updateData['rawList'])){
            return false;
        }
        if(!isset($updateData['packageList']) || empty($updateData['packageList'])){
            return false;
        }
        try{
            $result = $this->apiService->pushBatchUpdateProduct($updateData);
            if($result){
                if(isset($result['errorProduct']) && !empty($result['errorProduct'])){
                    $storeEntries = $this->apiService->getPlatformDataEntries('wuxiLab_not_exist_products','data_values');
                    /*if(!is_null($storeEntries) && count($storeEntries['products']) >= $this->apiService->getPlatformInfo('platform_params')['excelCreateLimit']){
                        SimpleKafka::produerSend(
                            [
                                'params' => ['products' => $storeEntries['products'],'type' => 'product'],
                                'consumer' => __CLASS__,
                                'method' => 'processProductsUpdateThroughtExcel'
                            ]
                        );
                        $this->apiService->removePlatformDataEntries('wuxiLab_not_exist_products');
                        $storeEntries = null;
                    }*/
                    foreach($result['errorProduct'] as $errorProduct){
                        if($errorProduct['reason'] == 'PRODUCT_NOT_EXIST'){
                            if(!is_null($storeEntries) && !empty($storeEntries['products'])){
                                if(!in_array($errorProduct['data'],$storeEntries['products'])){
                                    array_push($storeEntries['products'],$errorProduct['data']);
                                }
                            }else{
                                $storeEntries['products'][] = $errorProduct['data'];
                            }
                        }
                    }
                    $this->apiService->storePlatformDataEntries('wuxiLab_not_exist_products',['products' => $storeEntries['products']]);
                }
                //更新成功,批量更新包装规格
                $storeEntries = $this->apiService->getPlatformDataEntries('wuxiLab_do_not_update_products','data_values');
                if(!is_null($storeEntries) && count($storeEntries['products']) >= $this->apiService->getPlatformInfo('platform_params')['excelCreateLimit']){
                    SimpleKafka::produerSend(
                        [
                            'params' => ['products' => $storeEntries['products'],'type' => 'package'],
                            'consumer' => __CLASS__,
                            'method' => 'processProductsUpdateThroughtExcel'
                        ]
                    );
                    $this->apiService->removePlatformDataEntries('wuxiLab_do_not_update_products');
                }
                foreach($result['successProduct'] as $successProduct){
                    if(!is_null($storeEntries) && !empty($storeEntries['products'])){
                        if(!in_array($successProduct,$storeEntries['products'])){
                            array_push($storeEntries['products'],$successProduct);
                        }
                    }else{
                        $storeEntries['products'][] = $successProduct;
                    }
                }
            }
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':batchUpdateToWuxiLab', 'error');
            var_dump($exception->getMessage());
        }
    }

    /**
     * @ 获取api token
     * @return false|mixed
     */
    public function getToken(){
        try{
            $token = $this->apiService->getPlatformDataEntries('wuxilab_backlogin_token','data_values');
            if(empty($token)){
                $apiToken = $this->apiService->backgroundLogin();
                if($apiToken){
                    $backloginToken = [];
                    $backloginToken['currentTime'] = time();
                    $backloginToken['token'] = $apiToken;
                    $this->apiService->storePlatformDataEntries('wuxilab_backlogin_token',$backloginToken);
                    return $apiToken;
                }
            }else{
                //超过有效期，重新请求获取
                if(intval(gmdate('i',time() - intval($token['currentTime']))) > 30){
                    $apiToken = $this->apiService->backgroundLogin();
                    if($apiToken){
                        $apiToken['currentTime'] = time();
                        $this->apiService->storePlatformDataEntries('zkh_api_token',$apiToken);
                        return $apiToken['token'];
                    }
                }
                return $token['token'];
            }
        }catch(\Exception $exception){
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':token error', 'error');
            return false;
        }
    }



    /**
     * @初始化生成产品excel文档
     * @param $exportLimit
     */
    public function initCreateProductsToExcel($exportLimit)
    {
        $limit = $exportLimit;
        $page = 0;

        while(true) {
            $rawList = $this->rhawnChemicalsService->getChemicalRawList($page * $limit, $limit);
            if (!$rawList) {
                break;
            }
            $rawIdList = [];
            foreach ($rawList as $raw) {
                $rawIdList[] = $raw['r_id'];
            }
            $packages = $this->rhawnChemicalsService->getChemicalPackage($rawIdList);
            $newPackages = [];
            if($packages){
                foreach($packages as $pack){
                    $newPackages[$pack['r_code']] = $pack;
                }
            }
            if(!empty($rawList)){
                app(WuxiLabExport::class)->saveExcel(
                    ['rawList' => $rawList,'packageList' => $newPackages]
                );
            }
            break;
        }
    }

}
